import requests

from .. import settings


def _get_headers():
    headers = {
        'content-type': 'application/json'
    }

    if settings.PESCATORE_CLI_API_KEY is not None:
        headers['Authorization'] = '{0} {1}'.format(
            settings.PESCATORE_CLI_API_KEY_HEADER,
            settings.PESCATORE_CLI_API_KEY)

    elif settings.PESCATORE_CLI_JWT is not None:
        headers['Authorization'] = '{0} {1}'.format(
            settings.PESCATORE_CLI_JWT_HEADER,
            settings.PESCATORE_CLI_JWT)

    return headers


def make_request(path, params, payload=None, method='GET'):
    timeout = settings.REQUEST_TIMEOUT
    headers = _get_headers()
    url = '{base_url}{path}'.format(base_url=settings.PESCATORE_BASE_URL,
                                    path=path)
    if settings.DEBUG:
        print('CALLING', url, 'with method', method, 'and payload', payload)

    if method == 'GET':
        response = requests.get(url=url, headers=headers, params=params,
                                timeout=timeout)
    elif method == 'POST':
        response = requests.post(url=url, headers=headers, params=params,
                                 json=payload,
                                 timeout=timeout)
    elif method == 'DELETE':
        response = requests.delete(url=url, headers=headers, params=params,
                                   timeout=timeout)

    response.raise_for_status()

    response.encoding = response.apparent_encoding

    data = response.json()

    return data
